/* activities.js
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * SPDX-License-Identifier: GPL-2.0-or-later
 */

/* exported getExtension */

const Lang = imports.lang;

const Clutter = imports.gi.Clutter;
const St = imports.gi.St;

const ExtensionUtils = imports.misc.extensionUtils;

const Main = imports.ui.main;

const Me = ExtensionUtils.getCurrentExtension();

const Convenience = Me.imports.convenience;

const ACTIVITIES_DEFAULT = 0;
const ACTIVITIES_ICON = 1;
const ACTIVITIES_NONE = 2;

const KEY_SHOW_ACTIVITIES = 'show-activities';

const ActivitiesButton = new Lang.Class({
    Name: 'ActivitiesButton',

    _init() {
        Main.panel.statusArea.activities.actor.remove_actor(Main.panel.statusArea.activities._label);
        this._hbox = new St.BoxLayout({ style_class: 'panel-status-menu-box' });
        this._icon = new St.Icon({ icon_name: 'start-here-symbolic', style_class: 'system-status-icon' });
        this._hbox.add_child(this._icon);
        this._hbox.add_child(Main.panel.statusArea.activities._label);
        Main.panel.statusArea.activities.actor.add_child(this._hbox);
        this._settings = Convenience.getSettings();
        this._settingsChangedId = this._settings.connect('changed::%s'.format(KEY_SHOW_ACTIVITIES), this._onChangedShowActivities.bind(this));
        this._onChangedShowActivities();
    },

    _onChangedShowActivities() {
        let showActivities = this._settings.get_enum(KEY_SHOW_ACTIVITIES);
        Main.panel.statusArea.activities._label.visible = showActivities === ACTIVITIES_DEFAULT;
        this._icon.visible = showActivities === ACTIVITIES_ICON;
        this._setStyleParent(showActivities !== ACTIVITIES_NONE);
    },

    _setStyleParent(visible) {
        if (Main.panel.statusArea.activities.container.visible !== visible) {
            Main.panel.statusArea.activities.container.visible = visible && Main.sessionMode.currentMode !== 'unlock-dialog';
            let rtl = Main.panel.actor.get_text_direction() === Clutter.TextDirection.RTL;
            Main.panel._leftCorner.setStyleParent.call(Main.panel._leftCorner, Main.panel[rtl ? '_rightBox' : '_leftBox']);
        }
    },

    destroy() {
        this._settings.disconnect(this._settingsChangedId);
        Main.panel.statusArea.activities.actor.remove_actor(this._hbox);
        this._hbox.remove_actor(Main.panel.statusArea.activities._label);
        this._hbox.destroy_all_children();
        this._hbox.destroy();
        Main.panel.statusArea.activities.actor.add_actor(Main.panel.statusArea.activities._label);
        Main.panel.statusArea.activities._label.show();
        this._setStyleParent(true);
    }
});

function getExtension() {
    return new ActivitiesButton();
}
