/* dash.js
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * SPDX-License-Identifier: GPL-2.0-or-later
 */

/* exported getExtension */

const Lang = imports.lang;

const ExtensionUtils = imports.misc.extensionUtils;

const Main = imports.ui.main;

const Me = ExtensionUtils.getCurrentExtension();

const Convenience = Me.imports.convenience;

const KEY_SHOW_DASH = 'show-dash';
const KEY_SHOW_DASH_APPLICATIONS = 'show-dash-applications';

const Dash = new Lang.Class({
    Name: 'Dash',

    _init() {
        this._settings = Convenience.getSettings();
        this._settingsChangedId = [
            this._settings.connect('changed::%s'.format(KEY_SHOW_DASH), this._onChangedShowDash.bind(this)),
            this._settings.connect('changed::%s'.format(KEY_SHOW_DASH_APPLICATIONS), this._onChangedShowDashApplications.bind(this)),
        ];
        this._notifyMappedId = Main.overview._dash._box.connect('notify::mapped', this._onChangedShowDashApplications.bind(this));
        this._onChangedShowDash();
        this._onChangedShowDashApplications();
    },

    _onChangedShowDash() {
        let showDash = this._settings.get_boolean(KEY_SHOW_DASH);
        this._updateVisibilityDash(showDash);
    },

    _onChangedShowDashApplications() {
        let showDashApplications = this._settings.get_boolean(KEY_SHOW_DASH_APPLICATIONS);
        this._updateVisibilityDashApplications(showDashApplications);
    },

    _updateVisibilityDash(visible) {
        Main.overview._dash._container.visible = visible;
    },

    _updateVisibilityDashApplications(visible) {
        Main.overview._dash._showAppsIcon._iconActor.visible = visible;
    },

    destroy() {
        Main.overview._dash._box.disconnect(this._notifyMappedId);
        this._settingsChangedId.forEach(id => {
            this._settings.disconnect(id);
        });
        this._updateVisibilityDashApplications(true);
        this._updateVisibilityDash(true);
    }
});

function getExtension() {
    return new Dash();
}
