/* dateMenu.js
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * SPDX-License-Identifier: GPL-2.0-or-later
 */

/* exported getExtension */

const Lang = imports.lang;

const Clutter = imports.gi.Clutter;
const St = imports.gi.St;

const ExtensionUtils = imports.misc.extensionUtils;

const Main = imports.ui.main;

const Me = ExtensionUtils.getCurrentExtension();

const Convenience = Me.imports.convenience;

const KEY_SHOW_EVENTS_ICON = 'show-events-icon';

const DateMenuButton = new Lang.Class({
    Name: 'DateMenuButton',

    _init() {
        this._icon = new St.Icon({ icon_name: 'x-office-calendar-symbolic', style_class: 'system-status-icon', icon_size: 16, y_expand: true, y_align: Clutter.ActorAlign.CENTER });
        Main.panel.statusArea.dateMenu.actor.get_children()[0].insert_child_at_index(this._icon, 1);
        this._dateMenuChangedId = [
            Main.panel.statusArea.dateMenu._messageList._eventsSection._list.connect('actor-added', this._updateVisibility.bind(this)),
            Main.panel.statusArea.dateMenu._messageList._eventsSection._list.connect('actor-removed', this._updateVisibility.bind(this)),
        ];
        this._settings = Convenience.getSettings();
        this._settingsChangedId = this._settings.connect('changed::%s'.format(KEY_SHOW_EVENTS_ICON), this._updateVisibility.bind(this));
        this._updateVisibility();
    },

    _updateVisibility() {
        let showEventsIcon = this._settings.get_boolean(KEY_SHOW_EVENTS_ICON);
        let numEvents = Main.panel.statusArea.dateMenu._messageList._eventsSection._list.get_n_children();
        this._icon.visible = showEventsIcon && numEvents > 0;
    },

    destroy() {
        this._dateMenuChangedId.forEach(id => {
            Main.panel.statusArea.dateMenu._messageList._eventsSection._list.disconnect(id);
        });
        this._settings.disconnect(this._settingsChangedId);
        Main.panel.statusArea.dateMenu.actor.get_children()[0].remove_child(this._icon);
        this._icon.destroy();
    }
});

function getExtension() {
    return new DateMenuButton();
}
