/* keyboard.js
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * SPDX-License-Identifier: GPL-2.0-or-later
 */

/* exported getExtension */

const Lang = imports.lang;

const ExtensionUtils = imports.misc.extensionUtils;

const Main = imports.ui.main;
const PopupMenu = imports.ui.popupMenu;

const StatusKeyboard  = imports.ui.status.keyboard;

const Me = ExtensionUtils.getCurrentExtension();

const Convenience = Me.imports.convenience;

const KEY_ALWAYS_SHOW = 'always-show-input-sources-status';

const InputSourceIndicator = new Lang.Class({
    Name: 'InputSourceIndicator',

    _init() {
        Main.panel.statusArea.keyboard._currentSourceChanged = function(manager, oldSource) {
            StatusKeyboard.InputSourceIndicator.prototype._currentSourceChanged.call(this, manager, oldSource);
            let alwaysShow = Convenience.getSettings().get_boolean(KEY_ALWAYS_SHOW);
            let nVisibleSources = Object.keys(this._inputSourceManager.inputSources).length;
            if (alwaysShow && nVisibleSources < 2) {
                this.actor.show();
                this._menuItems[0].setOrnament(PopupMenu.Ornament.DOT);
                this._menuItems[0].setSensitive(false);
                this._indicatorLabels[0].show();
            }
        };
        this._settings = Convenience.getSettings();
        this._settingsChangedId = this._settings.connect('changed::%s'.format(KEY_ALWAYS_SHOW), this._updateVisibility.bind(this));
        if (Main.layoutManager._startingUp) {
            this._startupComplete = Main.layoutManager.connect('startup-complete', () => {
                this._updateVisibility();
                Main.layoutManager.disconnect(this._startupComplete);
            });
        } else {
            this._updateVisibility();
        }
    },

    _updateVisibility() {
        Main.panel.statusArea.keyboard._currentSourceChanged.call(Main.panel.statusArea.keyboard);
    },

    destroy() {
        this._settings.disconnect(this._settingsChangedId);
        Main.panel.statusArea.keyboard._currentSourceChanged = StatusKeyboard.InputSourceIndicator.prototype._currentSourceChanged;
        this._updateVisibility();
    }
});

function getExtension() {
    return new InputSourceIndicator();
}
